@@ -3,10 +3,20 @@ Wammu
 
 GUI pro Gammu.
 
-.. image:: https://hosted.weblate.org/widgets/gammu-status-badge.png
+.. image:: https://hosted.weblate.org/widgets/gammu/-/svg-badge.svg
     :alt: Stav překladu :target:
     https://hosted.weblate.org/engage/gammu/?utm_source=widget
 
+.. image:: https://landscape.io/github/gammu/wammu/master/landscape.svg?style=flat
+    :target: https://landscape.io/github/gammu/wammu/master :alt: Zdraví kódu
+
+.. image:: https://img.shields.io/gratipay/Gammu.svg
+    :alt: Gratipay :target: https://gratipay.com/Gammu/
+
+.. image:: https://www.bountysource.com/badge/team?team_id=23177&style=bounties_received
+    :alt: Bountysource :target:
+    https://www.bountysource.com/teams/gammu/issues?utm_source=Gammu&utm_medium=shield&utm_campaign=bounties_received
+
 Domovská stránka
 ================
 
